#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Common Dial, a custom Qt widget
# Copyright (C) 2011-2022 Filipe Coelho <falktx@falktx.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License, or any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# For a full copy of the GNU General Public License see the doc/GPL.txt file.

# ---------------------------------------------------------------------------------------------------------------------
# Imports (Global)

from math import isnan

from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt, QPointF, QRectF
from PyQt5.QtGui import QColor, QFont, QLinearGradient, QPainter
from PyQt5.QtWidgets import QDial

# ---------------------------------------------------------------------------------------------------------------------
# Widget Class

# to be implemented by subclasses
    #def updateSizes(self):
    #def paintDial(self, painter):

class CommonDial(QDial):
    # enum CustomPaintMode
    CUSTOM_PAINT_MODE_NULL        = 0 # default (NOTE: only this mode has label gradient)
    CUSTOM_PAINT_MODE_CARLA_WET   = 1 # color blue-green gradient (reserved #3)
    CUSTOM_PAINT_MODE_CARLA_VOL   = 2 # color blue (reserved #3)
    CUSTOM_PAINT_MODE_CARLA_L     = 3 # color yellow (reserved #4)
    CUSTOM_PAINT_MODE_CARLA_R     = 4 # color yellow (reserved #4)
    CUSTOM_PAINT_MODE_CARLA_PAN   = 5 # color yellow (reserved #3)
    CUSTOM_PAINT_MODE_COLOR       = 6 # color, selectable (reserved #3)
    CUSTOM_PAINT_MODE_ZITA        = 7 # custom zita knob (reserved #6)
    CUSTOM_PAINT_MODE_NO_GRADIENT = 8 # skip label gradient

    # enum Orientation
    HORIZONTAL = 0
    VERTICAL   = 1

    HOVER_MIN = 0
    HOVER_MAX = 9

    MODE_DEFAULT = 0
    MODE_LINEAR = 1

    # signals
    dragStateChanged = pyqtSignal(bool)
    realValueChanged = pyqtSignal(float)

    def __init__(self, parent, index):
        QDial.__init__(self, parent)

        self.fDialMode = self.MODE_LINEAR

        self.fMinimum   = 0.0
        self.fMaximum   = 1.0
        self.fRealValue = 0.0
        self.fPrecision = 10000
        self.fIsInteger = False

        self.fIsHovered = False
        self.fIsPressed = False
        self.fHoverStep = self.HOVER_MIN

        self.fLastDragPos = None
        self.fLastDragValue = 0.0

        self.fIndex = index

        self.fLabel     = ""
        self.fLabelPos  = QPointF(0.0, 0.0)
        self.fLabelFont = QFont(self.font())
        self.fLabelFont.setPixelSize(8)
        self.fLabelWidth  = 0
        self.fLabelHeight = 0

        if self.palette().window().color().lightness() > 100:
            # Light background
            c = self.palette().dark().color()
            self.fLabelGradientColor1 = c
            self.fLabelGradientColor2 = QColor(c.red(), c.green(), c.blue(), 0)
            self.fLabelGradientColorT = [self.palette().buttonText().color(), self.palette().mid().color()]
        else:
            # Dark background
            self.fLabelGradientColor1 = QColor(0, 0, 0, 255)
            self.fLabelGradientColor2 = QColor(0, 0, 0, 0)
            self.fLabelGradientColorT = [Qt.white, Qt.darkGray]

        self.fLabelGradient = QLinearGradient(0, 0, 0, 1)
        self.fLabelGradient.setColorAt(0.0, self.fLabelGradientColor1)
        self.fLabelGradient.setColorAt(0.6, self.fLabelGradientColor1)
        self.fLabelGradient.setColorAt(1.0, self.fLabelGradientColor2)

        self.fLabelGradientRect = QRectF(0.0, 0.0, 0.0, 0.0)

        self.fCustomPaintMode  = self.CUSTOM_PAINT_MODE_NULL
        self.fCustomPaintColor = QColor(0xff, 0xff, 0xff)

        # Fake internal value, custom precision
        QDial.setMinimum(self, 0)
        QDial.setMaximum(self, self.fPrecision)
        QDial.setValue(self, 0)

        self.valueChanged.connect(self.slot_valueChanged)

    def forceWhiteLabelGradientText(self):
        self.fLabelGradientColor1 = QColor(0, 0, 0, 255)
        self.fLabelGradientColor2 = QColor(0, 0, 0, 0)
        self.fLabelGradientColorT = [Qt.white, Qt.darkGray]

    def setLabelColor(self, enabled, disabled):
        self.fLabelGradientColor1 = QColor(0, 0, 0, 255)
        self.fLabelGradientColor2 = QColor(0, 0, 0, 0)
        self.fLabelGradientColorT = [enabled, disabled]

    def getIndex(self):
        return self.fIndex

    def setIndex(self, index):
        self.fIndex = index

    def setPrecision(self, value, isInteger):
        self.fPrecision = value
        self.fIsInteger = isInteger
        QDial.setMaximum(self, int(value))

    def setMinimum(self, value):
        self.fMinimum = value

    def setMaximum(self, value):
        self.fMaximum = value

    def rvalue(self):
        return self.fRealValue

    def setValue(self, value, emitSignal=False):
        if self.fRealValue == value or isnan(value):
            return

        if value <= self.fMinimum:
            qtValue = 0
            self.fRealValue = self.fMinimum

        elif value >= self.fMaximum:
            qtValue = int(self.fPrecision)
            self.fRealValue = self.fMaximum

        else:
            qtValue = round(float(value - self.fMinimum) / float(self.fMaximum - self.fMinimum) * self.fPrecision)
            self.fRealValue = value

        # Block change signal, we'll handle it ourselves
        self.blockSignals(True)
        QDial.setValue(self, qtValue)
        self.blockSignals(False)

        if emitSignal:
            self.realValueChanged.emit(self.fRealValue)

    def setCustomPaintMode(self, paintMode):
        if self.fCustomPaintMode == paintMode:
            return

        self.fCustomPaintMode = paintMode
        self.update()

    def setCustomPaintColor(self, color):
        if self.fCustomPaintColor == color:
            return

        self.fCustomPaintColor = color
        self.update()

    def setLabel(self, label):
        if self.fLabel == label:
            return

        self.fLabel = label
        self.updateSizes()
        self.update()

    @pyqtSlot(int)
    def slot_valueChanged(self, value):
        self.fRealValue = float(value)/self.fPrecision * (self.fMaximum - self.fMinimum) + self.fMinimum
        self.realValueChanged.emit(self.fRealValue)

    def enterEvent(self, event):
        self.fIsHovered = True
        if self.fHoverStep == self.HOVER_MIN:
            self.fHoverStep = self.HOVER_MIN + 1
        QDial.enterEvent(self, event)

    def leaveEvent(self, event):
        self.fIsHovered = False
        if self.fHoverStep == self.HOVER_MAX:
            self.fHoverStep = self.HOVER_MAX - 1
        QDial.leaveEvent(self, event)

    def mousePressEvent(self, event):
        if self.fDialMode == self.MODE_DEFAULT:
            QDial.mousePressEvent(self, event)
            return

        if event.button() == Qt.LeftButton:
            self.fIsPressed = True
            self.fLastDragPos = event.pos()
            self.fLastDragValue = self.fRealValue
            self.dragStateChanged.emit(True)

    def mouseMoveEvent(self, event):
        if self.fDialMode == self.MODE_DEFAULT:
            QDial.mouseMoveEvent(self, event)
            return

        if not self.fIsPressed:
            return

        diff  = (self.fMaximum - self.fMinimum) / 4.0
        pos   = event.pos()
        dx    = diff * float(pos.x() - self.fLastDragPos.x()) / self.width()
        dy    = diff * float(pos.y() - self.fLastDragPos.y()) / self.height()
        value = self.fLastDragValue + dx - dy

        if value < self.fMinimum:
            value = self.fMinimum
        elif value > self.fMaximum:
            value = self.fMaximum
        elif self.fIsInteger:
            value = float(round(value))

        self.setValue(value, True)

    def mouseReleaseEvent(self, event):
        if self.fDialMode == self.MODE_DEFAULT:
            QDial.mouseReleaseEvent(self, event)
            return

        if self.fIsPressed:
            self.fIsPressed = False
            self.dragStateChanged.emit(False)

    def paintEvent(self, event):
        painter = QPainter(self)
        event.accept()

        painter.save()
        painter.setRenderHint(QPainter.Antialiasing, True)

        if self.fLabel:
            if self.fCustomPaintMode == self.CUSTOM_PAINT_MODE_NULL:
                painter.setPen(self.fLabelGradientColor2)
                painter.setBrush(self.fLabelGradient)
                painter.drawRect(self.fLabelGradientRect)

            painter.setFont(self.fLabelFont)
            painter.setPen(self.fLabelGradientColorT[0 if self.isEnabled() else 1])
            painter.drawText(self.fLabelPos, self.fLabel)

        self.paintDial(painter)

        painter.restore()

    def resizeEvent(self, event):
        QDial.resizeEvent(self, event)
        self.updateSizes()

# ---------------------------------------------------------------------------------------------------------------------



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../../resources/ui/carla_add_jack.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(458, 546)
        self.verticalLayout = QtWidgets.QVBoxLayout(Dialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.l_note_features = QtWidgets.QLabel(Dialog)
        self.l_note_features.setObjectName("l_note_features")
        self.verticalLayout.addWidget(self.l_note_features)
        self.group_command = QtWidgets.QGroupBox(Dialog)
        self.group_command.setObjectName("group_command")
        self.gridLayout = QtWidgets.QGridLayout(self.group_command)
        self.gridLayout.setObjectName("gridLayout")
        spacerItem = QtWidgets.QSpacerItem(20, 60, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem, 0, 0, 3, 1)
        self.label_10 = QtWidgets.QLabel(self.group_command)
        self.label_10.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_10.setObjectName("label_10")
        self.gridLayout.addWidget(self.label_10, 0, 1, 1, 1)
        self.le_name = QtWidgets.QLineEdit(self.group_command)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.le_name.sizePolicy().hasHeightForWidth())
        self.le_name.setSizePolicy(sizePolicy)
        self.le_name.setObjectName("le_name")
        self.gridLayout.addWidget(self.le_name, 0, 2, 1, 2)
        spacerItem1 = QtWidgets.QSpacerItem(20, 60, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem1, 0, 4, 3, 1)
        self.label_5 = QtWidgets.QLabel(self.group_command)
        self.label_5.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_5.setObjectName("label_5")
        self.gridLayout.addWidget(self.label_5, 1, 1, 1, 1)
        self.rb_template = QtWidgets.QRadioButton(self.group_command)
        self.rb_template.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.rb_template.sizePolicy().hasHeightForWidth())
        self.rb_template.setSizePolicy(sizePolicy)
        self.rb_template.setObjectName("rb_template")
        self.gridLayout.addWidget(self.rb_template, 1, 2, 1, 1)
        self.rb_custom = QtWidgets.QRadioButton(self.group_command)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.rb_custom.sizePolicy().hasHeightForWidth())
        self.rb_custom.setSizePolicy(sizePolicy)
        self.rb_custom.setChecked(True)
        self.rb_custom.setObjectName("rb_custom")
        self.gridLayout.addWidget(self.rb_custom, 1, 3, 1, 1)
        self.stackedWidget = QtWidgets.QStackedWidget(self.group_command)
        self.stackedWidget.setObjectName("stackedWidget")
        self.page_template = QtWidgets.QWidget()
        self.page_template.setObjectName("page_template")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.page_template)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.l_template = QtWidgets.QLabel(self.page_template)
        self.l_template.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.l_template.setObjectName("l_template")
        self.horizontalLayout_2.addWidget(self.l_template)
        self.cb_template = QtWidgets.QComboBox(self.page_template)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cb_template.sizePolicy().hasHeightForWidth())
        self.cb_template.setSizePolicy(sizePolicy)
        self.cb_template.setEditable(False)
        self.cb_template.setObjectName("cb_template")
        self.horizontalLayout_2.addWidget(self.cb_template)
        self.stackedWidget.addWidget(self.page_template)
        self.page_command = QtWidgets.QWidget()
        self.page_command.setObjectName("page_command")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.page_command)
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.l_command = QtWidgets.QLabel(self.page_command)
        self.l_command.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.l_command.setObjectName("l_command")
        self.horizontalLayout_3.addWidget(self.l_command)
        self.le_command = QtWidgets.QLineEdit(self.page_command)
        self.le_command.setObjectName("le_command")
        self.horizontalLayout_3.addWidget(self.le_command)
        self.stackedWidget.addWidget(self.page_command)
        self.gridLayout.addWidget(self.stackedWidget, 2, 1, 1, 3)
        self.verticalLayout.addWidget(self.group_command)
        self.group_setup = QtWidgets.QGroupBox(Dialog)
        self.group_setup.setObjectName("group_setup")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.group_setup)
        self.gridLayout_2.setObjectName("gridLayout_2")
        spacerItem2 = QtWidgets.QSpacerItem(20, 1, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem2, 2, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem3)
        self.label_6 = QtWidgets.QLabel(self.group_setup)
        self.label_6.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout.addWidget(self.label_6)
        self.cb_session_mgr = QtWidgets.QComboBox(self.group_setup)
        self.cb_session_mgr.setObjectName("cb_session_mgr")
        self.cb_session_mgr.addItem("")
        self.cb_session_mgr.addItem("")
        self.cb_session_mgr.setItemText(1, "LADISH (SIGUSR1)")
        self.cb_session_mgr.addItem("")
        self.cb_session_mgr.setItemText(2, "NSM")
        self.horizontalLayout.addWidget(self.cb_session_mgr)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem4)
        self.gridLayout_2.addLayout(self.horizontalLayout, 0, 1, 1, 8)
        self.label_3 = QtWidgets.QLabel(self.group_setup)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_3.sizePolicy().hasHeightForWidth())
        self.label_3.setSizePolicy(sizePolicy)
        self.label_3.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_3.setObjectName("label_3")
        self.gridLayout_2.addWidget(self.label_3, 2, 1, 1, 1)
        self.sb_audio_ins = QtWidgets.QSpinBox(self.group_setup)
        self.sb_audio_ins.setMaximum(64)
        self.sb_audio_ins.setObjectName("sb_audio_ins")
        self.gridLayout_2.addWidget(self.sb_audio_ins, 2, 2, 1, 1)
        spacerItem5 = QtWidgets.QSpacerItem(20, 1, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem5, 2, 3, 1, 1)
        self.line = QtWidgets.QFrame(self.group_setup)
        self.line.setLineWidth(0)
        self.line.setMidLineWidth(1)
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridLayout_2.addWidget(self.line, 2, 4, 2, 1)
        spacerItem6 = QtWidgets.QSpacerItem(20, 1, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem6, 2, 5, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.group_setup)
        self.label_7.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_7.setObjectName("label_7")
        self.gridLayout_2.addWidget(self.label_7, 2, 6, 1, 1)
        self.sb_midi_ins = QtWidgets.QSpinBox(self.group_setup)
        self.sb_midi_ins.setMaximum(1)
        self.sb_midi_ins.setObjectName("sb_midi_ins")
        self.gridLayout_2.addWidget(self.sb_midi_ins, 2, 7, 1, 1)
        spacerItem7 = QtWidgets.QSpacerItem(1, 1, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem7, 2, 8, 1, 1)
        spacerItem8 = QtWidgets.QSpacerItem(20, 1, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem8, 3, 0, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.group_setup)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_4.sizePolicy().hasHeightForWidth())
        self.label_4.setSizePolicy(sizePolicy)
        self.label_4.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_4.setObjectName("label_4")
        self.gridLayout_2.addWidget(self.label_4, 3, 1, 1, 1)
        self.sb_audio_outs = QtWidgets.QSpinBox(self.group_setup)
        self.sb_audio_outs.setMaximum(64)
        self.sb_audio_outs.setObjectName("sb_audio_outs")
        self.gridLayout_2.addWidget(self.sb_audio_outs, 3, 2, 1, 1)
        spacerItem9 = QtWidgets.QSpacerItem(20, 1, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem9, 3, 3, 1, 1)
        spacerItem10 = QtWidgets.QSpacerItem(20, 1, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem10, 3, 5, 1, 1)
        self.label_8 = QtWidgets.QLabel(self.group_setup)
        self.label_8.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_8.setObjectName("label_8")
        self.gridLayout_2.addWidget(self.label_8, 3, 6, 1, 1)
        self.sb_midi_outs = QtWidgets.QSpinBox(self.group_setup)
        self.sb_midi_outs.setMaximum(1)
        self.sb_midi_outs.setObjectName("sb_midi_outs")
        self.gridLayout_2.addWidget(self.sb_midi_outs, 3, 7, 1, 1)
        spacerItem11 = QtWidgets.QSpacerItem(1, 1, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem11, 3, 8, 1, 1)
        self.cb_manage_window = QtWidgets.QCheckBox(self.group_setup)
        self.cb_manage_window.setObjectName("cb_manage_window")
        self.gridLayout_2.addWidget(self.cb_manage_window, 1, 2, 1, 7)
        self.verticalLayout.addWidget(self.group_setup)
        self.group_workarounds = QtWidgets.QGroupBox(Dialog)
        self.group_workarounds.setObjectName("group_workarounds")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.group_workarounds)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.cb_external_start = QtWidgets.QCheckBox(self.group_workarounds)
        self.cb_external_start.setObjectName("cb_external_start")
        self.gridLayout_3.addWidget(self.cb_external_start, 4, 1, 1, 1)
        self.cb_capture_first_window = QtWidgets.QCheckBox(self.group_workarounds)
        self.cb_capture_first_window.setEnabled(False)
        self.cb_capture_first_window.setObjectName("cb_capture_first_window")
        self.gridLayout_3.addWidget(self.cb_capture_first_window, 0, 1, 1, 1)
        spacerItem12 = QtWidgets.QSpacerItem(20, 1, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem12, 0, 0, 1, 1)
        spacerItem13 = QtWidgets.QSpacerItem(135, 1, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem13, 0, 2, 1, 1)
        self.cb_buffers_addition_mode = QtWidgets.QCheckBox(self.group_workarounds)
        self.cb_buffers_addition_mode.setObjectName("cb_buffers_addition_mode")
        self.gridLayout_3.addWidget(self.cb_buffers_addition_mode, 2, 1, 1, 1)
        self.cb_out_midi_mixdown = QtWidgets.QCheckBox(self.group_workarounds)
        self.cb_out_midi_mixdown.setObjectName("cb_out_midi_mixdown")
        self.gridLayout_3.addWidget(self.cb_out_midi_mixdown, 1, 1, 1, 1)
        self.verticalLayout.addWidget(self.group_workarounds)
        self.group_error = QtWidgets.QFrame(Dialog)
        self.group_error.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.group_error.setFrameShadow(QtWidgets.QFrame.Raised)
        self.group_error.setObjectName("group_error")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.group_error)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.ico_error = QtWidgets.QLabel(self.group_error)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(16)
        sizePolicy.setVerticalStretch(16)
        sizePolicy.setHeightForWidth(self.ico_error.sizePolicy().hasHeightForWidth())
        self.ico_error.setSizePolicy(sizePolicy)
        self.ico_error.setMaximumSize(QtCore.QSize(16, 16))
        self.ico_error.setText("")
        self.ico_error.setPixmap(QtGui.QPixmap(":/16x16/dialog-cancel.svgz"))
        self.ico_error.setScaledContents(True)
        self.ico_error.setObjectName("ico_error")
        self.horizontalLayout_4.addWidget(self.ico_error)
        self.l_error = QtWidgets.QLabel(self.group_error)
        self.l_error.setObjectName("l_error")
        self.horizontalLayout_4.addWidget(self.l_error)
        self.verticalLayout.addWidget(self.group_error)
        spacerItem14 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem14)
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(Dialog)
        self.stackedWidget.setCurrentIndex(1)
        self.cb_session_mgr.setCurrentIndex(0)
        self.buttonBox.accepted.connect(Dialog.accept) # type: ignore
        self.buttonBox.rejected.connect(Dialog.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Add JACK Application"))
        self.l_note_features.setText(_translate("Dialog", "Note: Features not implemented yet are greyed out"))
        self.group_command.setTitle(_translate("Dialog", "Application"))
        self.label_10.setText(_translate("Dialog", "Name:"))
        self.label_5.setText(_translate("Dialog", "Application:"))
        self.rb_template.setText(_translate("Dialog", "From template"))
        self.rb_custom.setText(_translate("Dialog", "Custom"))
        self.l_template.setText(_translate("Dialog", "Template:"))
        self.l_command.setText(_translate("Dialog", "Command:"))
        self.group_setup.setTitle(_translate("Dialog", "Setup"))
        self.label_6.setText(_translate("Dialog", "Session Manager:"))
        self.cb_session_mgr.setItemText(0, _translate("Dialog", "None"))
        self.label_3.setText(_translate("Dialog", "Audio inputs:"))
        self.label_7.setText(_translate("Dialog", "MIDI inputs:"))
        self.label_4.setText(_translate("Dialog", "Audio outputs:"))
        self.label_8.setText(_translate("Dialog", "MIDI outputs:"))
        self.cb_manage_window.setText(_translate("Dialog", "Take control of main application window"))
        self.group_workarounds.setTitle(_translate("Dialog", "Workarounds"))
        self.cb_external_start.setText(_translate("Dialog", "Wait for external application start (Advanced, for Debug only)"))
        self.cb_capture_first_window.setText(_translate("Dialog", "Capture only the first X11 Window"))
        self.cb_buffers_addition_mode.setText(_translate("Dialog", "Use previous client output buffer as input for the next client"))
        self.cb_out_midi_mixdown.setText(_translate("Dialog", "Simulate 16 JACK MIDI outputs, with MIDI channel as port index"))
        self.l_error.setText(_translate("Dialog", "Error here"))
import resources_rc



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# PatchBay Canvas Themes
# Copyright (C) 2010-2019 Filipe Coelho <falktx@falktx.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License, or any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# For a full copy of the GNU General Public License see the doc/GPL.txt file.

# ------------------------------------------------------------------------------------------------------------
# Imports (Global)

from PyQt5.QtCore import Qt
from PyQt5.QtGui import QColor, QFont, QPen, QPixmap

# ------------------------------------------------------------------------------------------------------------

class Theme(object):
    # enum PortType
    THEME_PORT_SQUARE = 0
    THEME_PORT_POLYGON = 1

    # enum List
    THEME_MODERN_DARK = 0
    THEME_MODERN_DARK_TINY = 1
    THEME_MODERN_LIGHT = 2
    THEME_CLASSIC_DARK = 3
    THEME_OOSTUDIO = 4
    THEME_MAX = 5

    # enum BackgroundType
    THEME_BG_SOLID = 0
    THEME_BG_GRADIENT = 1

    def __init__(self, idx):
        object.__init__(self)

        self.idx = idx

        if idx == self.THEME_MODERN_DARK:
            # Canvas
            self.canvas_bg = QColor(0, 0, 0)

            # Boxes
            self.box_pen = QPen(QColor(76, 77, 78), 1, Qt.SolidLine)
            self.box_pen_sel = QPen(QColor(206, 207, 208), 1, Qt.DashLine)
            self.box_bg_1 = QColor(32, 34, 35)
            self.box_bg_2 = QColor(43, 47, 48)
            self.box_shadow = QColor(89, 89, 89, 180)
            self.box_header_pixmap = None
            self.box_header_height = 24
            self.box_header_spacing = 0

            self.box_text = QPen(QColor(240, 240, 240), 0)
            self.box_text_sel = self.box_text
            self.box_text_ypos = 16
            self.box_font_name = "Deja Vu Sans"
            self.box_font_size = 11
            self.box_font_state = QFont.Bold

            self.box_bg_type = self.THEME_BG_GRADIENT
            self.box_use_icon = True

            # Ports
            self.port_text = QPen(QColor(250, 250, 250), 0)
            self.port_text_ypos = 12
            self.port_bg_pixmap = None
            self.port_font_name = "Deja Vu Sans"
            self.port_font_size = 11
            self.port_font_state = QFont.Normal
            self.port_mode = self.THEME_PORT_POLYGON

            self.port_audio_jack_pen = QPen(QColor(63, 90, 126), 1)
            self.port_audio_jack_pen_sel = QPen(QColor(63 + 30, 90 + 30, 126 + 30), 1)
            self.port_midi_jack_pen = QPen(QColor(159, 44, 42), 1)
            self.port_midi_jack_pen_sel = QPen(QColor(159 + 30, 44 + 30, 42 + 30), 1)
            self.port_midi_alsa_pen = QPen(QColor(93, 141, 46), 1)
            self.port_midi_alsa_pen_sel = QPen(QColor(93 + 30, 141 + 30, 46 + 30), 1)
            self.port_parameter_pen = QPen(QColor(137, 76, 43), 1)
            self.port_parameter_pen_sel = QPen(QColor(137 + 30, 76 + 30, 43 + 30), 1)

            self.port_audio_jack_bg = QColor(35, 61, 99)
            self.port_audio_jack_bg_sel = QColor(35 + 50, 61 + 50, 99 + 50)
            self.port_midi_jack_bg = QColor(120, 15, 16)
            self.port_midi_jack_bg_sel = QColor(120 + 50, 15 + 50, 16 + 50)
            self.port_midi_alsa_bg = QColor(64, 112, 18)
            self.port_midi_alsa_bg_sel = QColor(64 + 50, 112 + 50, 18 + 50)
            self.port_parameter_bg = QColor(101, 47, 16)
            self.port_parameter_bg_sel = QColor(101 + 50, 47 + 50, 16 + 50)

            self.port_audio_jack_text = self.port_text
            self.port_audio_jack_text_sel = self.port_text
            self.port_midi_jack_text = self.port_text
            self.port_midi_jack_text_sel = self.port_text
            self.port_midi_alsa_text = self.port_text
            self.port_midi_alsa_text_sel = self.port_text
            self.port_parameter_text = self.port_text
            self.port_parameter_text_sel = self.port_text

            self.port_height = 16
            self.port_offset = 0
            self.port_spacing = 2
            self.port_spacingT = 2

            # Lines
            self.line_audio_jack = QColor(63, 90, 126)
            self.line_audio_jack_sel = QColor(63 + 90, 90 + 90, 126 + 90)
            self.line_audio_jack_glow = QColor(100, 100, 200)
            self.line_midi_jack = QColor(159, 44, 42)
            self.line_midi_jack_sel = QColor(159 + 90, 44 + 90, 42 + 90)
            self.line_midi_jack_glow = QColor(200, 100, 100)
            self.line_midi_alsa = QColor(93, 141, 46)
            self.line_midi_alsa_sel = QColor(93 + 90, 141 + 90, 46 + 90)
            self.line_midi_alsa_glow = QColor(100, 200, 100)
            self.line_parameter = QColor(137, 76, 43)
            self.line_parameter_sel = QColor(137 + 90, 76 + 90, 43 + 90)
            self.line_parameter_glow = QColor(166, 133, 133)

            self.rubberband_pen = QPen(QColor(206, 207, 208), 1, Qt.SolidLine)
            self.rubberband_brush = QColor(76, 77, 78, 100)

        elif idx == self.THEME_MODERN_DARK_TINY:
            # Canvas
            self.canvas_bg = QColor(0, 0, 0)

            # Boxes
            self.box_pen = QPen(QColor(76, 77, 78), 1, Qt.SolidLine)
            self.box_pen_sel = QPen(QColor(206, 207, 208), 1, Qt.DashLine)
            self.box_bg_1 = QColor(32, 34, 35)
            self.box_bg_2 = QColor(43, 47, 48)
            self.box_shadow = QColor(89, 89, 89, 180)
            self.box_header_pixmap = None
            self.box_header_height = 14
            self.box_header_spacing = 0

            self.box_text = QPen(QColor(240, 240, 240), 0)
            self.box_text_sel = self.box_text
            self.box_text_ypos = 10
            self.box_font_name = "Deja Vu Sans"
            self.box_font_size = 10
            self.box_font_state = QFont.Bold

            self.box_bg_type = self.THEME_BG_GRADIENT
            self.box_use_icon = False

            # Ports
            self.port_text = QPen(QColor(250, 250, 250), 0)
            self.port_text_ypos = 9
            self.port_bg_pixmap = None
            self.port_font_name = "Deja Vu Sans"
            self.port_font_size = 9
            self.port_font_state = QFont.Normal
            self.port_mode = self.THEME_PORT_POLYGON

            self.port_audio_jack_pen = QPen(QColor(63, 90, 126), 1)
            self.port_audio_jack_pen_sel = QPen(QColor(63 + 30, 90 + 30, 126 + 30), 1)
            self.port_midi_jack_pen = QPen(QColor(159, 44, 42), 1)
            self.port_midi_jack_pen_sel = QPen(QColor(159 + 30, 44 + 30, 42 + 30), 1)
            self.port_midi_alsa_pen = QPen(QColor(93, 141, 46), 1)
            self.port_midi_alsa_pen_sel = QPen(QColor(93 + 30, 141 + 30, 46 + 30), 1)
            self.port_parameter_pen = QPen(QColor(137, 76, 43), 1)
            self.port_parameter_pen_sel = QPen(QColor(137 + 30, 76 + 30, 43 + 30), 1)

            self.port_audio_jack_bg = QColor(35, 61, 99)
            self.port_audio_jack_bg_sel = QColor(35 + 50, 61 + 50, 99 + 50)
            self.port_midi_jack_bg = QColor(120, 15, 16)
            self.port_midi_jack_bg_sel = QColor(120 + 50, 15 + 50, 16 + 50)
            self.port_midi_alsa_bg = QColor(64, 112, 18)
            self.port_midi_alsa_bg_sel = QColor(64 + 50, 112 + 50, 18 + 50)
            self.port_parameter_bg = QColor(101, 47, 16)
            self.port_parameter_bg_sel = QColor(101 + 50, 47 + 50, 16 + 50)

            self.port_audio_jack_text = self.port_text
            self.port_audio_jack_text_sel = self.port_text
            self.port_midi_jack_text = self.port_text
            self.port_midi_jack_text_sel = self.port_text
            self.port_midi_alsa_text = self.port_text
            self.port_midi_alsa_text_sel = self.port_text
            self.port_parameter_text = self.port_text
            self.port_parameter_text_sel = self.port_text

            self.port_height = 12
            self.port_offset = 0
            self.port_spacing = 1
            self.port_spacingT = 1

            # Lines
            self.line_audio_jack = QColor(63, 90, 126)
            self.line_audio_jack_sel = QColor(63 + 90, 90 + 90, 126 + 90)
            self.line_audio_jack_glow = QColor(100, 100, 200)
            self.line_midi_jack = QColor(159, 44, 42)
            self.line_midi_jack_sel = QColor(159 + 90, 44 + 90, 42 + 90)
            self.line_midi_jack_glow = QColor(200, 100, 100)
            self.line_midi_alsa = QColor(93, 141, 46)
            self.line_midi_alsa_sel = QColor(93 + 90, 141 + 90, 46 + 90)
            self.line_midi_alsa_glow = QColor(100, 200, 100)
            self.line_parameter = QColor(137, 76, 43)
            self.line_parameter_sel = QColor(137 + 90, 76 + 90, 43 + 90)
            self.line_parameter_glow = QColor(166, 133, 133)

            self.rubberband_pen = QPen(QColor(206, 207, 208), 1, Qt.SolidLine)
            self.rubberband_brush = QColor(76, 77, 78, 100)

        elif idx == self.THEME_MODERN_LIGHT:
            # Canvas
            self.canvas_bg = QColor(248, 249, 250)

            # Boxes
            self.box_pen = QPen(QColor(176, 177, 178), 1, Qt.SolidLine)
            self.box_pen_sel = QPen(QColor(1, 2, 3), 2, Qt.DashLine)
            self.box_bg_1 = QColor(250, 250, 250)
            self.box_bg_2 = QColor(200, 200, 200)
            self.box_shadow = QColor(1, 1, 1, 100)
            self.box_header_pixmap = None
            self.box_header_height = 24
            self.box_header_spacing = 0

            self.box_text = QPen(QColor(1, 1, 1), 0)
            self.box_text_sel = self.box_text
            self.box_text_ypos = 16
            self.box_font_name = "Ubuntu"
            self.box_font_size = 11
            self.box_font_state = QFont.Bold

            self.box_bg_type = self.THEME_BG_GRADIENT
            self.box_use_icon = True

            # Ports
            self.port_text = QPen(QColor(255, 255, 255), 1)
            self.port_text_ypos = 12
            self.port_bg_pixmap = None
            self.port_font_name = "Ubuntu"
            self.port_font_size = 11
            self.port_font_state = QFont.Bold
            self.port_mode = self.THEME_PORT_POLYGON

            self.port_audio_jack_pen = QPen(QColor(103, 130, 166), 2)
            self.port_audio_jack_pen_sel = QPen(QColor(103 + 136, 190 + 130, 226 + 130), 1)
            self.port_midi_jack_pen = QPen(QColor(159, 44, 42), 1)
            self.port_midi_jack_pen_sel = QPen(QColor(90 + 30, 44 + 30, 42 + 30), 1)
            self.port_midi_alsa_pen = QPen(QColor(93, 141, 46), 1)
            self.port_midi_alsa_pen_sel = QPen(QColor(93 + 30, 141 + 30, 46 + 30), 1)
            self.port_parameter_pen = QPen(QColor(137, 76, 43), 1)
            self.port_parameter_pen_sel = QPen(QColor(137 + 30, 76 + 30, 43 + 30), 1)

            self.port_audio_jack_bg = QColor(0, 0, 180)
            self.port_audio_jack_bg_sel = QColor(135 + 150, 161 + 150, 199 + 150)
            self.port_midi_jack_bg = QColor(130, 15, 16)
            self.port_midi_jack_bg_sel = QColor(90 + 30, 15 + 50, 16 + 50)
            self.port_midi_alsa_bg = QColor(64, 112, 18)
            self.port_midi_alsa_bg_sel = QColor(64 + 50, 112 + 50, 18 + 50)
            self.port_parameter_bg = QColor(101, 47, 16)
            self.port_parameter_bg_sel = QColor(101 + 50, 47 + 50, 16 + 50)

            self.port_audio_jack_text = self.port_text
            self.port_audio_jack_text_sel = self.port_text
            self.port_midi_jack_text = self.port_text
            self.port_midi_jack_text_sel = self.port_text
            self.port_midi_alsa_text = self.port_text
            self.port_midi_alsa_text_sel = self.port_text
            self.port_parameter_text = self.port_text
            self.port_parameter_text_sel = self.port_text

            self.port_height = 16
            self.port_offset = 0
            self.port_spacing = 2
            self.port_spacingT = 2

            # Lines
            self.line_audio_jack = QColor(63, 90, 126)
            self.line_audio_jack_sel = QColor(63 + 63, 90 + 90, 126 + 90)
            self.line_audio_jack_glow = QColor(100, 100, 200)
            self.line_midi_jack = QColor(159, 44, 42)
            self.line_midi_jack_sel = QColor(159 + 44, 44 + 90, 42 + 90)
            self.line_midi_jack_glow = QColor(200, 100, 100)
            self.line_midi_alsa = QColor(93, 141, 46)
            self.line_midi_alsa_sel = QColor(93 + 90, 141 + 90, 46 + 90)
            self.line_midi_alsa_glow = QColor(100, 200, 100)
            self.line_parameter = QColor(137, 43, 43)
            self.line_parameter_sel = QColor(137 + 90, 76 + 90, 43 + 90)
            self.line_parameter_glow = QColor(166, 133, 133)

            self.rubberband_pen = QPen(QColor(206, 207, 208), 1, Qt.SolidLine)
            self.rubberband_brush = QColor(76, 77, 78, 100)

        elif idx == self.THEME_CLASSIC_DARK:
            # Canvas
            self.canvas_bg = QColor(0, 0, 0)

            # Boxes
            self.box_pen = QPen(QColor(147 - 70, 151 - 70, 143 - 70), 2, Qt.SolidLine)
            self.box_pen_sel = QPen(QColor(147, 151, 143), 2, Qt.DashLine)
            self.box_bg_1 = QColor(30, 34, 36)
            self.box_bg_2 = QColor(30, 34, 36)
            self.box_shadow = QColor(89, 89, 89, 180)
            self.box_header_pixmap = None
            self.box_header_height = 19
            self.box_header_spacing = 0

            self.box_text = QPen(QColor(255, 255, 255), 0)
            self.box_text_sel = self.box_text
            self.box_text_ypos = 12
            self.box_font_name = "Sans"
            self.box_font_size = 12
            self.box_font_state = QFont.Normal

            self.box_bg_type = self.THEME_BG_GRADIENT
            self.box_use_icon = False

            # Ports
            self.port_text = QPen(QColor(250, 250, 250), 0)
            self.port_text_ypos = 11
            self.port_bg_pixmap = None
            self.port_font_name = "Sans"
            self.port_font_size = 11
            self.port_font_state = QFont.Normal
            self.port_mode = self.THEME_PORT_SQUARE

            self.port_audio_jack_pen = QPen(QColor(35, 61, 99), Qt.NoPen, 0)
            self.port_audio_jack_pen_sel = QPen(QColor(255, 0, 0), Qt.NoPen, 0)
            self.port_midi_jack_pen = QPen(QColor(120, 15, 16), Qt.NoPen, 0)
            self.port_midi_jack_pen_sel = QPen(QColor(255, 0, 0), Qt.NoPen, 0)
            self.port_midi_alsa_pen = QPen(QColor(63, 112, 19), Qt.NoPen, 0)
            self.port_midi_alsa_pen_sel = QPen(QColor(255, 0, 0), Qt.NoPen, 0)
            self.port_parameter_pen = QPen(QColor(101, 47, 17), Qt.NoPen, 0)
            self.port_parameter_pen_sel = QPen(QColor(255, 0, 0), Qt.NoPen, 0)

            self.port_audio_jack_bg = QColor(35, 61, 99)
            self.port_audio_jack_bg_sel = QColor(255, 0, 0)
            self.port_midi_jack_bg = QColor(120, 15, 16)
            self.port_midi_jack_bg_sel = QColor(255, 0, 0)
            self.port_midi_alsa_bg = QColor(63, 112, 19)
            self.port_midi_alsa_bg_sel = QColor(255, 0, 0)
            self.port_parameter_bg = QColor(101, 47, 17)
            self.port_parameter_bg_sel = QColor(255, 0, 0)

            self.port_audio_jack_text = self.port_text
            self.port_audio_jack_text_sel = self.port_text
            self.port_midi_jack_text = self.port_text
            self.port_midi_jack_text_sel = self.port_text
            self.port_midi_alsa_text = self.port_text
            self.port_midi_alsa_text_sel = self.port_text
            self.port_parameter_text = self.port_text
            self.port_parameter_text_sel = self.port_text

            self.port_height = 14
            self.port_offset = 0
            self.port_spacing = 1
            self.port_spacingT = 0

            # Lines
            self.line_audio_jack = QColor(53, 78, 116)
            self.line_audio_jack_sel = QColor(255, 0, 0)
            self.line_audio_jack_glow = QColor(255, 0, 0)
            self.line_midi_jack = QColor(139, 32, 32)
            self.line_midi_jack_sel = QColor(255, 0, 0)
            self.line_midi_jack_glow = QColor(255, 0, 0)
            self.line_midi_alsa = QColor(81, 130, 36)
            self.line_midi_alsa_sel = QColor(255, 0, 0)
            self.line_midi_alsa_glow = QColor(255, 0, 0)
            self.line_parameter = QColor(120, 65, 33)
            self.line_parameter_sel = QColor(255, 0, 0)
            self.line_parameter_glow = QColor(255, 0, 0)

            self.rubberband_pen = QPen(QColor(147, 151, 143), 2, Qt.SolidLine)
            self.rubberband_brush = QColor(35, 61, 99, 100)

        elif idx == self.THEME_OOSTUDIO:
            # Canvas
            self.canvas_bg = QColor(11, 11, 11)

            # Boxes
            self.box_pen = QPen(QColor(76, 77, 78), 1, Qt.SolidLine)
            self.box_pen_sel = QPen(QColor(189, 122, 214), 1, Qt.DashLine)
            self.box_bg_1 = QColor(46, 46, 46)
            self.box_bg_2 = QColor(23, 23, 23)
            self.box_shadow = QColor(89, 89, 89, 180)
            self.box_header_pixmap = QPixmap(":/bitmaps/canvas/frame_node_header.png")
            self.box_header_height = 22
            self.box_header_spacing = 6

            self.box_text = QPen(QColor(144, 144, 144), 0)
            self.box_text_sel = QPen(QColor(189, 122, 214), 0)
            self.box_text_ypos = 16
            self.box_font_name = "Deja Vu Sans"
            self.box_font_size = 11
            self.box_font_state = QFont.Bold

            self.box_bg_type = self.THEME_BG_SOLID
            self.box_use_icon = False

            # Ports
            normalPortBG = QColor(46, 46, 46)
            selPortBG = QColor(23, 23, 23)

            self.port_text = QPen(QColor(155, 155, 155), 0)
            self.port_text_ypos = 14
            self.port_bg_pixmap = QPixmap(":/bitmaps/canvas/frame_port_bg.png")
            self.port_font_name = "Deja Vu Sans"
            self.port_font_size = 11
            self.port_font_state = QFont.Normal
            self.port_mode = self.THEME_PORT_SQUARE

            self.port_audio_jack_pen = QPen(selPortBG, 2)
            self.port_audio_jack_pen_sel = QPen(QColor(1, 230, 238), 1)
            self.port_midi_jack_pen = QPen(selPortBG, 2)
            self.port_midi_jack_pen_sel = QPen(QColor(252, 118, 118), 1)
            self.port_midi_alsa_pen = QPen(selPortBG, 2)
            self.port_midi_alsa_pen_sel = QPen(QColor(129, 244, 118), 0)
            self.port_parameter_pen = QPen(selPortBG, 2)
            self.port_parameter_pen_sel = QPen(QColor(137, 76, 43), 1)

            self.port_audio_jack_bg = normalPortBG
            self.port_audio_jack_bg_sel = selPortBG
            self.port_midi_jack_bg = normalPortBG
            self.port_midi_jack_bg_sel = selPortBG
            self.port_midi_alsa_bg = normalPortBG
            self.port_midi_alsa_bg_sel = selPortBG
            self.port_parameter_bg = normalPortBG
            self.port_parameter_bg_sel = selPortBG

            self.port_audio_jack_text = self.port_text
            self.port_audio_jack_text_sel = self.port_audio_jack_pen_sel
            self.port_midi_jack_text = self.port_text
            self.port_midi_jack_text_sel = self.port_midi_jack_pen_sel
            self.port_midi_alsa_text = self.port_text
            self.port_midi_alsa_text_sel = self.port_midi_alsa_pen_sel
            self.port_parameter_text = self.port_text
            self.port_parameter_text_sel = self.port_parameter_pen_sel

            # missing, ports 2
            self.port_height = 21
            self.port_offset = 1
            self.port_spacing = 3
            self.port_spacingT = 0

            # Lines
            self.line_audio_jack = QColor(64, 64, 64)
            self.line_audio_jack_sel = QColor(1, 230, 238)
            self.line_audio_jack_glow = QColor(100, 200, 100)
            self.line_midi_jack = QColor(64, 64, 64)
            self.line_midi_jack_sel = QColor(252, 118, 118)
            self.line_midi_jack_glow = QColor(200, 100, 100)
            self.line_midi_alsa = QColor(64, 64, 64)
            self.line_midi_alsa_sel = QColor(129, 244, 118)
            self.line_midi_alsa_glow = QColor(100, 200, 100)
            self.line_parameter = QColor(64, 64, 64)
            self.line_parameter_sel = QColor(137+90, 76+90, 43+90)
            self.line_parameter_glow = QColor(166, 133, 133)

            self.rubberband_pen = QPen(QColor(1, 230, 238), 2, Qt.SolidLine)
            self.rubberband_brush = QColor(90, 90, 90, 100)

# ------------------------------------------------------------------------------------------------------------

def getDefaultTheme():
    return Theme.THEME_MODERN_DARK

def getThemeName(idx):
    if idx == Theme.THEME_MODERN_DARK:
        return "Modern Dark"
    if idx == Theme.THEME_MODERN_DARK_TINY:
        return "Modern Dark (Tiny)"
    if idx == Theme.THEME_MODERN_LIGHT:
        return "Modern Light"
    if idx == Theme.THEME_CLASSIC_DARK:
        return "Classic Dark"
    if idx == Theme.THEME_OOSTUDIO:
        return "OpenOctave Studio"
    return ""

def getDefaultThemeName():
    return "Modern Dark"

# ------------------------------------------------------------------------------------------------------------



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Collapsible Box, a custom Qt widget
# Copyright (C) 2019-2022 Filipe Coelho <falktx@falktx.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License, or any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# For a full copy of the GNU General Public License see the doc/GPL.txt file.

# ------------------------------------------------------------------------------------------------------------
# Imports (Global)

from PyQt5.QtCore import pyqtSlot, Qt
from PyQt5.QtWidgets import QFrame, QSizePolicy, QToolButton, QVBoxLayout, QWidget

# ------------------------------------------------------------------------------------------------------------
# Widget Class

class QToolButtonWithMouseTracking(QToolButton):
    def __init__(self, parent):
        QToolButton.__init__(self, parent)
        self._font = self.font()

    def enterEvent(self, event):
        self._font.setBold(True)
        self.setFont(self._font)
        QToolButton.enterEvent(self, event)

    def leaveEvent(self, event):
        self._font.setBold(False)
        self.setFont(self._font)
        QToolButton.leaveEvent(self, event)

class CollapsibleBox(QFrame):
    def __init__(self, title, parent):
        QFrame.__init__(self, parent)

        self.setFrameShape(QFrame.StyledPanel)
        self.setFrameShadow(QFrame.Raised)

        self.toggle_button = QToolButtonWithMouseTracking(self)
        self.toggle_button.setText(title)
        self.toggle_button.setCheckable(True)
        self.toggle_button.setChecked(True)
        self.toggle_button.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
        self.toggle_button.setToolButtonStyle(Qt.ToolButtonTextBesideIcon)
        self.toggle_button.setArrowType(Qt.DownArrow)
        self.toggle_button.toggled.connect(self.toolButtonPressed)

        self.content_area   = QWidget(self)
        self.content_layout = QVBoxLayout(self.content_area)
        self.content_layout.setContentsMargins(6, 2, 6, 0)
        self.content_layout.setSpacing(3)

        lay = QVBoxLayout(self)
        lay.setContentsMargins(0, 0, 0, 4)
        lay.setSpacing(1)
        lay.addWidget(self.toggle_button)
        lay.addWidget(self.content_area)

    @pyqtSlot(bool)
    def toolButtonPressed(self, toggled):
        self.content_area.setVisible(toggled)
        self.toggle_button.setArrowType(Qt.DownArrow if toggled else Qt.RightArrow)

    def getContentLayout(self):
        return self.content_layout

# ------------------------------------------------------------------------------------------------------------



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../../resources/ui/midipattern.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MidiPatternW(object):
    def setupUi(self, MidiPatternW):
        MidiPatternW.setObjectName("MidiPatternW")
        MidiPatternW.resize(755, 436)
        self.centralwidget = QtWidgets.QWidget(MidiPatternW)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.modeIndicator = ModeIndicator(self.centralwidget)
        self.modeIndicator.setMinimumSize(QtCore.QSize(30, 20))
        self.modeIndicator.setMaximumSize(QtCore.QSize(30, 20))
        self.modeIndicator.setObjectName("modeIndicator")
        self.horizontalLayout.addWidget(self.modeIndicator)
        self.timeSigLabel = QtWidgets.QLabel(self.centralwidget)
        self.timeSigLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.timeSigLabel.setObjectName("timeSigLabel")
        self.horizontalLayout.addWidget(self.timeSigLabel)
        self.timeSigBox = QtWidgets.QComboBox(self.centralwidget)
        self.timeSigBox.setEditable(True)
        self.timeSigBox.setObjectName("timeSigBox")
        self.timeSigBox.addItem("")
        self.timeSigBox.addItem("")
        self.timeSigBox.addItem("")
        self.timeSigBox.addItem("")
        self.timeSigBox.addItem("")
        self.timeSigBox.addItem("")
        self.horizontalLayout.addWidget(self.timeSigBox)
        spacerItem = QtWidgets.QSpacerItem(5, 5, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.measureLabel = QtWidgets.QLabel(self.centralwidget)
        self.measureLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.measureLabel.setObjectName("measureLabel")
        self.horizontalLayout.addWidget(self.measureLabel)
        self.measureBox = QtWidgets.QComboBox(self.centralwidget)
        self.measureBox.setObjectName("measureBox")
        self.measureBox.addItem("")
        self.measureBox.addItem("")
        self.measureBox.addItem("")
        self.measureBox.addItem("")
        self.measureBox.addItem("")
        self.measureBox.addItem("")
        self.measureBox.addItem("")
        self.measureBox.addItem("")
        self.measureBox.addItem("")
        self.measureBox.addItem("")
        self.measureBox.addItem("")
        self.measureBox.addItem("")
        self.measureBox.addItem("")
        self.measureBox.addItem("")
        self.measureBox.addItem("")
        self.measureBox.addItem("")
        self.horizontalLayout.addWidget(self.measureBox)
        spacerItem1 = QtWidgets.QSpacerItem(5, 5, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.defaultLengthLabel = QtWidgets.QLabel(self.centralwidget)
        self.defaultLengthLabel.setObjectName("defaultLengthLabel")
        self.horizontalLayout.addWidget(self.defaultLengthLabel)
        self.defaultLengthBox = QtWidgets.QComboBox(self.centralwidget)
        self.defaultLengthBox.setObjectName("defaultLengthBox")
        self.defaultLengthBox.addItem("")
        self.defaultLengthBox.addItem("")
        self.defaultLengthBox.addItem("")
        self.defaultLengthBox.addItem("")
        self.defaultLengthBox.addItem("")
        self.defaultLengthBox.addItem("")
        self.defaultLengthBox.addItem("")
        self.defaultLengthBox.addItem("")
        self.defaultLengthBox.addItem("")
        self.defaultLengthBox.addItem("")
        self.horizontalLayout.addWidget(self.defaultLengthBox)
        spacerItem2 = QtWidgets.QSpacerItem(5, 5, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem2)
        self.quantizeLabel = QtWidgets.QLabel(self.centralwidget)
        self.quantizeLabel.setObjectName("quantizeLabel")
        self.horizontalLayout.addWidget(self.quantizeLabel)
        self.quantizeBox = QtWidgets.QComboBox(self.centralwidget)
        self.quantizeBox.setObjectName("quantizeBox")
        self.quantizeBox.addItem("")
        self.quantizeBox.addItem("")
        self.quantizeBox.addItem("")
        self.quantizeBox.addItem("")
        self.quantizeBox.addItem("")
        self.quantizeBox.addItem("")
        self.quantizeBox.addItem("")
        self.quantizeBox.addItem("")
        self.quantizeBox.addItem("")
        self.quantizeBox.addItem("")
        self.horizontalLayout.addWidget(self.quantizeBox)
        spacerItem3 = QtWidgets.QSpacerItem(5, 5, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem3)
        self.hSlider = QtWidgets.QSlider(self.centralwidget)
        self.hSlider.setOrientation(QtCore.Qt.Horizontal)
        self.hSlider.setObjectName("hSlider")
        self.horizontalLayout.addWidget(self.hSlider)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.vSlider = QtWidgets.QSlider(self.centralwidget)
        self.vSlider.setOrientation(QtCore.Qt.Vertical)
        self.vSlider.setObjectName("vSlider")
        self.horizontalLayout_2.addWidget(self.vSlider)
        self.graphicsView = PianoRollView(self.centralwidget)
        self.graphicsView.setObjectName("graphicsView")
        self.horizontalLayout_2.addWidget(self.graphicsView)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        MidiPatternW.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MidiPatternW)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 755, 23))
        self.menubar.setObjectName("menubar")
        self.menu_File = QtWidgets.QMenu(self.menubar)
        self.menu_File.setObjectName("menu_File")
        self.menu_Edit = QtWidgets.QMenu(self.menubar)
        self.menu_Edit.setObjectName("menu_Edit")
        MidiPatternW.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MidiPatternW)
        self.statusbar.setObjectName("statusbar")
        MidiPatternW.setStatusBar(self.statusbar)
        self.act_file_quit = QtWidgets.QAction(MidiPatternW)
        self.act_file_quit.setObjectName("act_file_quit")
        self.act_edit_insert = QtWidgets.QAction(MidiPatternW)
        self.act_edit_insert.setCheckable(True)
        self.act_edit_insert.setObjectName("act_edit_insert")
        self.act_edit_velocity = QtWidgets.QAction(MidiPatternW)
        self.act_edit_velocity.setCheckable(True)
        self.act_edit_velocity.setObjectName("act_edit_velocity")
        self.act_edit_select_all = QtWidgets.QAction(MidiPatternW)
        self.act_edit_select_all.setObjectName("act_edit_select_all")
        self.menu_File.addAction(self.act_file_quit)
        self.menu_Edit.addAction(self.act_edit_insert)
        self.menu_Edit.addAction(self.act_edit_velocity)
        self.menu_Edit.addAction(self.act_edit_select_all)
        self.menubar.addAction(self.menu_File.menuAction())
        self.menubar.addAction(self.menu_Edit.menuAction())

        self.retranslateUi(MidiPatternW)
        self.timeSigBox.setCurrentIndex(0)
        self.measureBox.setCurrentIndex(3)
        self.defaultLengthBox.setCurrentIndex(4)
        self.quantizeBox.setCurrentIndex(4)
        self.act_file_quit.triggered.connect(MidiPatternW.close) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(MidiPatternW)

    def retranslateUi(self, MidiPatternW):
        _translate = QtCore.QCoreApplication.translate
        MidiPatternW.setWindowTitle(_translate("MidiPatternW", "MIDI Pattern"))
        self.timeSigLabel.setText(_translate("MidiPatternW", "Time Signature:"))
        self.timeSigBox.setItemText(0, _translate("MidiPatternW", "1/4"))
        self.timeSigBox.setItemText(1, _translate("MidiPatternW", "2/4"))
        self.timeSigBox.setItemText(2, _translate("MidiPatternW", "3/4"))
        self.timeSigBox.setItemText(3, _translate("MidiPatternW", "4/4"))
        self.timeSigBox.setItemText(4, _translate("MidiPatternW", "5/4"))
        self.timeSigBox.setItemText(5, _translate("MidiPatternW", "6/4"))
        self.measureLabel.setText(_translate("MidiPatternW", "Measures:"))
        self.measureBox.setItemText(0, _translate("MidiPatternW", "1"))
        self.measureBox.setItemText(1, _translate("MidiPatternW", "2"))
        self.measureBox.setItemText(2, _translate("MidiPatternW", "3"))
        self.measureBox.setItemText(3, _translate("MidiPatternW", "4"))
        self.measureBox.setItemText(4, _translate("MidiPatternW", "5"))
        self.measureBox.setItemText(5, _translate("MidiPatternW", "6"))
        self.measureBox.setItemText(6, _translate("MidiPatternW", "7"))
        self.measureBox.setItemText(7, _translate("MidiPatternW", "8"))
        self.measureBox.setItemText(8, _translate("MidiPatternW", "9"))
        self.measureBox.setItemText(9, _translate("MidiPatternW", "10"))
        self.measureBox.setItemText(10, _translate("MidiPatternW", "11"))
        self.measureBox.setItemText(11, _translate("MidiPatternW", "12"))
        self.measureBox.setItemText(12, _translate("MidiPatternW", "13"))
        self.measureBox.setItemText(13, _translate("MidiPatternW", "14"))
        self.measureBox.setItemText(14, _translate("MidiPatternW", "15"))
        self.measureBox.setItemText(15, _translate("MidiPatternW", "16"))
        self.defaultLengthLabel.setText(_translate("MidiPatternW", "Default Length:"))
        self.defaultLengthBox.setItemText(0, _translate("MidiPatternW", "1/16"))
        self.defaultLengthBox.setItemText(1, _translate("MidiPatternW", "1/15"))
        self.defaultLengthBox.setItemText(2, _translate("MidiPatternW", "1/12"))
        self.defaultLengthBox.setItemText(3, _translate("MidiPatternW", "1/9"))
        self.defaultLengthBox.setItemText(4, _translate("MidiPatternW", "1/8"))
        self.defaultLengthBox.setItemText(5, _translate("MidiPatternW", "1/6"))
        self.defaultLengthBox.setItemText(6, _translate("MidiPatternW", "1/4"))
        self.defaultLengthBox.setItemText(7, _translate("MidiPatternW", "1/3"))
        self.defaultLengthBox.setItemText(8, _translate("MidiPatternW", "1/2"))
        self.defaultLengthBox.setItemText(9, _translate("MidiPatternW", "1"))
        self.quantizeLabel.setText(_translate("MidiPatternW", "Quantize:"))
        self.quantizeBox.setItemText(0, _translate("MidiPatternW", "1/16"))
        self.quantizeBox.setItemText(1, _translate("MidiPatternW", "1/15"))
        self.quantizeBox.setItemText(2, _translate("MidiPatternW", "1/12"))
        self.quantizeBox.setItemText(3, _translate("MidiPatternW", "1/9"))
        self.quantizeBox.setItemText(4, _translate("MidiPatternW", "1/8"))
        self.quantizeBox.setItemText(5, _translate("MidiPatternW", "1/6"))
        self.quantizeBox.setItemText(6, _translate("MidiPatternW", "1/4"))
        self.quantizeBox.setItemText(7, _translate("MidiPatternW", "1/3"))
        self.quantizeBox.setItemText(8, _translate("MidiPatternW", "1/2"))
        self.quantizeBox.setItemText(9, _translate("MidiPatternW", "1"))
        self.menu_File.setTitle(_translate("MidiPatternW", "&File"))
        self.menu_Edit.setTitle(_translate("MidiPatternW", "&Edit"))
        self.act_file_quit.setText(_translate("MidiPatternW", "&Quit"))
        self.act_file_quit.setShortcut(_translate("MidiPatternW", "Esc"))
        self.act_edit_insert.setText(_translate("MidiPatternW", "&Insert Mode"))
        self.act_edit_insert.setShortcut(_translate("MidiPatternW", "F"))
        self.act_edit_velocity.setText(_translate("MidiPatternW", "&Velocity Mode"))
        self.act_edit_velocity.setShortcut(_translate("MidiPatternW", "D"))
        self.act_edit_select_all.setText(_translate("MidiPatternW", "Select All"))
        self.act_edit_select_all.setShortcut(_translate("MidiPatternW", "A"))
from widgets.pianoroll import ModeIndicator, PianoRollView



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# PatchBay Canvas engine using QGraphicsView/Scene
# Copyright (C) 2010-2019 Filipe Coelho <falktx@falktx.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License, or any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# For a full copy of the GNU General Public License see the doc/GPL.txt file.

# ------------------------------------------------------------------------------------------------------------
# Imports (Global)

from PyQt5.QtWidgets import QGraphicsDropShadowEffect

# ------------------------------------------------------------------------------------------------------------
# Imports (Custom)

from . import (
    canvas,
    PORT_TYPE_AUDIO_JACK,
    PORT_TYPE_MIDI_ALSA,
    PORT_TYPE_MIDI_JACK,
    PORT_TYPE_PARAMETER,
)

# ------------------------------------------------------------------------------------------------------------

class CanvasPortGlow(QGraphicsDropShadowEffect):
    def __init__(self, port_type, parent):
        QGraphicsDropShadowEffect.__init__(self, parent)

        self.setBlurRadius(12)
        self.setOffset(0, 0)

        if port_type == PORT_TYPE_AUDIO_JACK:
            self.setColor(canvas.theme.line_audio_jack_glow)
        elif port_type == PORT_TYPE_MIDI_JACK:
            self.setColor(canvas.theme.line_midi_jack_glow)
        elif port_type == PORT_TYPE_MIDI_ALSA:
            self.setColor(canvas.theme.line_midi_alsa_glow)
        elif port_type == PORT_TYPE_PARAMETER:
            self.setColor(canvas.theme.line_parameter_glow)

# ------------------------------------------------------------------------------------------------------------



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# PatchBay Canvas engine using QGraphicsView/Scene
# Copyright (C) 2010-2019 Filipe Coelho <falktx@falktx.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License, or any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# For a full copy of the GNU General Public License see the doc/GPL.txt file.

# ------------------------------------------------------------------------------------------------------------
# Imports (Global)

from PyQt5.QtCore import qCritical, QRectF
from PyQt5.QtGui import QPainter
from PyQt5.QtSvg import QGraphicsSvgItem, QSvgRenderer
from PyQt5.QtWidgets import QGraphicsColorizeEffect

# ------------------------------------------------------------------------------------------------------------
# Imports (Custom)

from . import (
    canvas,
    icon2str,
    CanvasIconType,
    ICON_APPLICATION,
    ICON_HARDWARE,
    ICON_DISTRHO,
    ICON_FILE,
    ICON_PLUGIN,
    ICON_LADISH_ROOM,
)

# ------------------------------------------------------------------------------------------------------------

class CanvasIcon(QGraphicsSvgItem):
    def __init__(self, icon, name, parent):
        QGraphicsSvgItem.__init__(self)
        self.setParentItem(parent)

        self.m_renderer = None
        self.p_size = QRectF(0, 0, 0, 0)

        self.m_colorFX = QGraphicsColorizeEffect(self)
        self.m_colorFX.setColor(canvas.theme.box_text.color())

        self.setGraphicsEffect(self.m_colorFX)
        self.setIcon(icon, name)

    def setIcon(self, icon, name):
        name = name.lower()
        icon_path = ""

        if icon == ICON_APPLICATION:
            self.p_size = QRectF(3, 2, 19, 18)

            if "audacious" in name:
                icon_path = ":/scalable/pb_audacious.svg"
                self.p_size = QRectF(5, 4, 16, 16)
            elif "clementine" in name:
                icon_path = ":/scalable/pb_clementine.svg"
                self.p_size = QRectF(5, 4, 16, 16)
            elif "distrho" in name:
                icon_path = ":/scalable/pb_distrho.svg"
                self.p_size = QRectF(5, 4, 16, 16)
            elif "jamin" in name:
                icon_path = ":/scalable/pb_jamin.svg"
                self.p_size = QRectF(5, 3, 16, 16)
            elif "mplayer" in name:
                icon_path = ":/scalable/pb_mplayer.svg"
                self.p_size = QRectF(5, 4, 16, 16)
            elif "vlc" in name:
                icon_path = ":/scalable/pb_vlc.svg"
                self.p_size = QRectF(5, 3, 16, 16)

            else:
                icon_path = ":/scalable/pb_generic.svg"
                self.p_size = QRectF(4, 3, 16, 16)

        elif icon == ICON_HARDWARE:
            icon_path = ":/scalable/pb_hardware.svg"
            self.p_size = QRectF(5, 2, 16, 16)

        elif icon == ICON_DISTRHO:
            icon_path = ":/scalable/pb_distrho.svg"
            self.p_size = QRectF(5, 4, 16, 16)

        elif icon == ICON_FILE:
            icon_path = ":/scalable/pb_file.svg"
            self.p_size = QRectF(5, 4, 16, 16)

        elif icon == ICON_PLUGIN:
            icon_path = ":/scalable/pb_plugin.svg"
            self.p_size = QRectF(5, 4, 16, 16)

        elif icon == ICON_LADISH_ROOM:
            # TODO - make a unique ladish-room icon
            icon_path = ":/scalable/pb_hardware.svg"
            self.p_size = QRectF(5, 2, 16, 16)

        else:
            self.p_size = QRectF(0, 0, 0, 0)
            qCritical("PatchCanvas::CanvasIcon.setIcon(%s, %s) - unsupported icon requested" % (
                      icon2str(icon), name.encode()))
            return

        self.m_renderer = QSvgRenderer(icon_path, canvas.scene)
        self.setSharedRenderer(self.m_renderer)
        self.update()

    def type(self):
        return CanvasIconType

    def boundingRect(self):
        return self.p_size

    def paint(self, painter, option, widget):
        if not self.m_renderer:
            QGraphicsSvgItem.paint(self, painter, option, widget)
            return

        painter.save()
        painter.setRenderHint(QPainter.Antialiasing, False)
        painter.setRenderHint(QPainter.TextAntialiasing, False)
        self.m_renderer.render(painter, self.p_size)
        painter.restore()

# ------------------------------------------------------------------------------------------------------------
